Message

Enum Message 

pub enum Message {
    Hello,
    WorkerInfo(WorkerInfo),
    SingleOp {
        layer_name: String,
        x: RawTensor,
        index_pos: usize,
        block_idx: usize,
    },
    Batch {
        x: RawTensor,
        batch: Vec<(String, usize, usize)>,
    },
    Tensor(RawTensor),
    Goodbye,
    LayerAssignment {
        layers: Vec<String>,
        model_hash: String,
    },
    LayerAssignmentAck {
        needs_data: bool,
    },
    ModelDataChunk {
        filename: String,
        offset: u64,
        total_size: u64,
        data: Vec<u8>,
    },
    ModelDataDone,
    WorkerReady,
    WorkerError {
        message: String,
    },
}
A Cake protocol message.

Variants



Hello

First message sent.



WorkerInfo(WorkerInfo)

Message that the worker sends when a master connects with runtime information.



SingleOp

Single inference operation for a given layer.

Fields

layer_name: String
index_pos: usize
block_idx: usize


Batch

Batched inference operations over a Tensor.

Fields

batch: Vec<(String, usize, usize)>


Tensor(RawTensor)

A message to transmit tensors.



Goodbye

Last message sent.



LayerAssignment

Master tells worker which layers to serve.

Fields

layers: Vec<String>
model_hash: String

Short hash of model config for cache keying.



LayerAssignmentAck

Worker tells master whether it needs model data.

Fields

needs_data: bool


ModelDataChunk

Chunk of model file data from master to worker.

Fields

filename: String
offset: u64
total_size: u64
data: Vec<u8>


ModelDataDone

All model files have been sent.



WorkerReady

Worker has loaded all assigned layers and is ready for inference.



WorkerError

Worker encountered an error during inference.

Fields

message: String

Implementations

Source

impl Message

pub fn single_op( layer_name: &str, x: &Tensor, index_pos: usize, block_idx: usize, ) -> Self

Create a Message::SingleOp message.

pub fn from_tensor(x: &Tensor) -> Self

Create a Message::Tensor message.

pub fn from_batch(x: &Tensor, batch: Vec<(String, usize, usize)>) -> Self

Create a Message::Batch message.

pub async fn from_reader<R>(reader: &mut R) -> Result<(usize, Self)>
where R: AsyncReadExt + Unpin,

Read a Message with the provided reader.

pub async fn from_reader_buf<R>( reader: &mut R, buf: &mut Vec<u8>, ) -> Result<(usize, Self)>
where R: AsyncReadExt + Unpin,

Read a Message, reusing buf to avoid per-message heap allocation.

pub async fn to_writer<W>(&self, writer: &mut W) -> Result<usize>
where W: AsyncWriteExt + Unpin,

Write a Message with the provided writer.

pub async fn to_writer_buf<W>( &self, writer: &mut W, buf: &mut Vec<u8>, ) -> Result<usize>
where W: AsyncWriteExt + Unpin,

Write a Message, reusing buf to avoid per-message heap allocation.