Client

Struct Client 

pub struct Client { /* private fields */ }
A client object used by the master to connect and orchestrate the workers. From the Cake perspective, each worker is a server and the master uses multiple Client instances to connect to them.

Implementations

Source

impl Client

pub async fn new( device: Device, address: &str, layer_name: &str, cluster_key: Option<&str>, ) -> Result<Self>

Connects to the given worker address. NOTE: device and layer_name here are only passed for std::fmt::Display. If cluster_key is provided, mutual PSK authentication is performed before any protocol messages.