pub struct Token {
pub id: u32,
pub text: Option<String>,
pub is_end_of_stream: bool,
}Expand description
A token.
Fields
id: u32Numerical identifier.
text: Option<String>Resolved text token or None if not present in the tokenizer.
is_end_of_stream: boolSet to true if the stream of tokens is over.