pub fn list_models() -> Result<Vec<LocalModel>>Expand description
Scan all known locations for models and return a list of discovered models.
pub fn list_models() -> Result<Vec<LocalModel>>Scan all known locations for models and return a list of discovered models.