pub struct Master<TG, IG> {
pub ctx: Context,
pub llm_model: Option<Box<TG>>,
pub sd_model: Option<Box<IG>>,
}Expand description
A master connects to, communicates with and orchestrates the workers.
Fields
ctx: Contextllm_model: Option<Box<TG>>sd_model: Option<Box<IG>>Implementations
Sourceimpl<TG: TextGenerator + Send + Sync + 'static, IG: ImageGenerator + Send + Sync + 'static> Master<TG, IG>
impl<TG: TextGenerator + Send + Sync + 'static, IG: ImageGenerator + Send + Sync + 'static> Master<TG, IG>
pub async fn run(self) -> Result<()>
Sourcepub async fn generate_text<S>(
&mut self,
max_tokens: Option<usize>,
stream: S,
) -> Result<()>
pub async fn generate_text<S>( &mut self, max_tokens: Option<usize>, stream: S, ) -> Result<()>
Start the generation loop and call the stream function for every token.
max_tokens overrides the default sample length if provided.
pub async fn generate_image<F>( &mut self, args: ImageGenerationArgs, callback: F, ) -> Result<()>