pub struct Args {Show 26 fields
pub device: usize,
pub mode: Mode,
pub name: Option<String>,
pub address: String,
pub api: Option<String>,
pub model: String,
pub topology: Option<String>,
pub prompt: String,
pub system_prompt: String,
pub seed: u64,
pub sample_len: usize,
pub temperature: f64,
pub top_p: Option<f64>,
pub top_k: Option<usize>,
pub repeat_penalty: f32,
pub repeat_last_n: usize,
pub dtype: Option<String>,
pub cluster_key: Option<String>,
pub discovery_timeout: u64,
pub ui_auth: Option<String>,
pub topology_override: Option<Topology>,
pub cpu: bool,
pub model_type: ModelType,
pub text_model_arch: TextModelArch,
pub sd_args: SDArgs,
pub sd_img_gen_args: ImageGenerationArgs,
}Fields
device: usizeGPU device index.
mode: ModeMode (set by subcommand, not directly by user).
name: Option<String>Worker name.
address: StringBinding address and port for workers.
api: Option<String>Enable OpenAI compatible chat completion API.
model: StringPath to model directory, or HuggingFace repo ID (e.g., Qwen/Qwen2.5-Coder-1.5B-Instruct).
topology: Option<String>Topology file.
prompt: StringThe initial prompt.
system_prompt: StringThe system prompt.
seed: u64The seed to use when generating random samples.
sample_len: usizeThe length of the sample to generate (in tokens).
temperature: f64The temperature used to generate samples.
top_p: Option<f64>Nucleus sampling probability cutoff.
top_k: Option<usize>Only sample among the top K samples.
repeat_penalty: f32Penalty to be applied for repeating tokens, 1. means no penalty.
repeat_last_n: usizeThe context size to consider for the repeat penalty.
dtype: Option<String>Use different dtype than f16
cluster_key: Option<String>Cluster key for zero-config mDNS discovery and PSK authentication. When set on both master and workers, enables automatic discovery, layer assignment, and model data push without topology files.
discovery_timeout: u64How long to wait for worker discovery (seconds). 0 = skip discovery.
ui_auth: Option<String>Optional basic auth for the web UI (format: “user:pass”).
topology_override: Option<Topology>Topology built during zero-config setup (not a CLI arg).
cpu: boolRun on CPU rather than on GPU.
model_type: ModelTypetext_model_arch: TextModelArchText model architecture (auto-detected from config.json if omitted).
sd_args: SDArgssd_img_gen_args: ImageGenerationArgsTrait Implementations
Sourceimpl Args for Args
impl Args for Args
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl CommandFactory for Args
impl CommandFactory for Args
Sourceimpl FromArgMatches for Args
impl FromArgMatches for Args
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl Parser for Args
impl Parser for Args
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)